==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/sluzebnicesty/radeksluzebnicestydialog.php <==
<?php
/**
 * stanislav.elbl, 19.10.2021 22:04
 */

namespace RonPortal\SluzebniCesty;

use Ron\Controls\FormField;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBRecord;
use Ron\DB\SqlStatement;
use Ron\StringUtils;
use RonPortal\Controls\RonPortalForm;
use RonPortal\RonPortalSettings;

class RadekSluzebniCestyDialog extends RonPortalForm
{
    protected $sluzebniCesta;


    /**
     * @param Database $database
     * @param SluzebniCesta $sluzebniCesta
     */
    function __construct($database, $sluzebniCesta)
    {
        parent::__construct($database, 'new', true);

        $this ->sluzebniCesta = $sluzebniCesta;

        $this ->cssClass = 'large-form rondialog ronform form-25-75';
        $this ->code = 'formradeksc';

        $this ->stornoAction = "#";

        $this ->htmlParams = array_merge($this ->htmlParams, [
            'id' => 'radek_sc_dialog',
            //'data-ronform-url' => '?menuid=sluzebnicestyjs&action=radeksc&idsc=' . $this ->sluzebniCesta ->id,
            'data-ronform-submit-url' => '?menuid=sluzebnicestyjs&action=zapisradeksc',
            'data-ronform-after-submit' => 'reload',
            'title' => \Ron\ronText('Radek_sluzebni_cesty')
        ]);

        $this ->sqlTableName = 'RadekSluzebniCesty';

        $this ->setXmlEventsName('SC_RADEK');

        $vychoziHodnoty = $this ->nactiHodnotyProNovyRadek();

        $this ->addField(FormField::FIELD_TYPE_HIDDEN)
            ->setFieldName('SluzebniCesta_ID') ->setDefaultValue($this ->sluzebniCesta ->id) ->setPrimary(true)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-sluzebnicesta_id')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'SluzebniCesta_ID']);

        $idParams = $this ->database ->createParameters();
        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('CisloRadku') ->setPrimary(true)
            ->setIdSqlFilter(new SqlStatement('SluzebniCesta_ID = ' . $idParams ->addParameter($this ->sluzebniCesta ->id), $idParams))
            ->addFieldCssClass('ronform-field')
            ->setCode('field-cisloradku')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'CisloRadku']);

        $this ->addField(FormField::FIELD_TYPE_DATEANDTIME)
            ->setFieldName('DatumCasOd') ->setCaption('Datum_a_cas')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-datumcasod')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'DatumCasOd'])
            ->setOtherHtmlParams2(['data-ronform-field-name' => 'DatumCasOd_time'])
            ->setDefaultValue([
                $vychoziHodnoty['datum'] ? StringUtils::format('date', $vychoziHodnoty['datum']) : '',
                $vychoziHodnoty['cas'] ? StringUtils::format('time', $vychoziHodnoty['cas']) : ''
            ]);

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('KodOperace') ->setCaption('Operace_sc')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-kodoperace')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'KodOperace'])
            ->setTranslationPrefix('db_operacedochazky_popis_')
            ->setSelectSql(
                'SELECT Kod, Popis FROM OperaceDochazky' .
                ' WHERE ' . ($this ->sluzebniCesta ->zahranicni ? 'UdalostZahranicniSC' : 'UdalostSluzebniCesty') . ' = 1 AND (%FILTER%)' .
                ' ORDER BY %ORDER%',
                '1 = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Misto') ->setCaption('Misto_sc')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-misto')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Misto'])
            ->setTranslationPrefix('db_mistosluzebnicesty_popis_')
            ->setSelectSql(
                'SELECT Kod, Popis FROM MistoSluzebniCesty' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                'Aktivni = 1',
                'Popis'
            );

        $this ->addField()
            ->setFieldName('Popis') ->setCaption('Popis_radku_sc') ->setMaxLength(160)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-popis')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Popis']);

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Stat') ->setCaption('Stat') ->setDefaultValue($vychoziHodnoty['stat'])
            ->addFieldCssClass('ronform-field ronselect')
            ->setCode('field-stat')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Stat'])
            ->setTranslationPrefix('db_stat_popis_')
            ->setSelectSql(
                'SELECT Kod, Popis FROM Stat' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                'PovolitVeSluzCeste = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DopravniProstredek') ->setCaption('Dopravni_prostredek') ->setDefaultValue($vychoziHodnoty['dopravniProstredek']) // default podle SC.
            ->addFieldCssClass('ronform-field')
            ->setCode('field-dopravniprostredek')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'DopravniProstredek'])
            ->setTranslationPrefix('db_dopravniprostredek_popis_')
            ->setVisible(false) // defaultne skryte, protoze je zadano uz v hlavicce SC
            ->setSelectSql(
                'SELECT Kod, Popis FROM DopravniProstredek' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                '1 = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_S') ->setCaption('Pocet_snidani') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_s')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_S', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_O') ->setCaption('Pocet_obedu') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_o')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_O', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_V') ->setCaption('Pocet_veceri') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_v')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_V', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setCaption('Poznamka') ->setMaxLength(250)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-poznamka')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Poznamka']);


        $this ->loadConfiguration();
    }


    public function getWhereCondition()
    {
        $params = $this ->database ->createParameters();

        $cisloRadku = isset($_POST['CisloRadku'])
            ? (int)$_POST['CisloRadku']
            : (int)$_GET['record'];

        return new SqlStatement(
            'SluzebniCesta_ID = ' . $params ->addParameter($this ->sluzebniCesta ->id) .
            ' AND CisloRadku = ' . $params ->addParameter($cisloRadku),
            $params);
    }


    /**
     * Urci vychozi hodnoty podle hlavicky sluzebni cesty a jiz existujicich radku
     * @return array
     * @throws \Ron\DB\DBException
     */
    private function nactiHodnotyProNovyRadek()
    {
        $params = $this ->database ->createParameters();

        $sql =
            'SELECT SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat, SluzebniCesta.DopravniProstredek, MAX(RadekSluzebniCesty.DatumCasOd)' .
            '  FROM SluzebniCesta LEFT OUTER JOIN RadekSluzebniCesty ON RadekSluzebniCesty.SluzebniCesta_ID = SluzebniCesta.Id ' .
            ' WHERE SluzebniCesta.Id = ' . $params ->addParameter((int)$this->sluzebniCesta ->id) .
            ' GROUP BY SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat, SluzebniCesta.DopravniProstredek';

        $cursor = $this ->database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        $cas = null;
        $datum = null;

        if ($row) {
            if ($row[4]) {
                // nejedna se o prvni radek - datum podle posledniho zaznamu, cas nevyplneny
                $datum = $cursor ->stringToTimestamp($row[4]);
            } else {
                // jedna se o prvni radek - datum a cas podle zacatku sl. cesty
                $datum = $cas = $cursor ->stringToTimestamp($row[0]);
            }
        }

        return [
            'datum' => $datum,
            'cas' => $cas,
            'stat' => $row[2],
            'dopravniProstredek' => $row[3]
        ];
    }


    /**
     * @param DBRecord $rec
     * @throws \Exception
     */
    private function zkontrolujZaznam($rec)
    {
        $cas = $rec['DatumCasOd'];

        if (!$this ->sluzebniCesta ->pocatekKonecPodleRadku) {
            // U sluzebni cesty neni nastaveno, ze se ma pocitat datum a cas pocatku a konce podle radku
            // Kontrola, jestli je zadany cas v rozsahu casu sluzebni cesty
            if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_CASY_AUTOMATICKY)) {
                // cas pocatku a konce se nastavuje automaticky - kontroluje jenom datum
                if ($cas < DateUtils::startOfTheDay($this ->sluzebniCesta->datumCasOd) || $cas > DateUtils::endOfTheDay($this ->sluzebniCesta->datumCasDo)) {
                    throw new \Exception(\Ron\ronText('Datum_mimo_rozsah_sc') . ' ' .
                        date('j.n.Y', $this ->sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y', $this ->sluzebniCesta->datumCasDo));
                }
            } else {
                // ... ani cas se nenastavuje automaticky
                if ($cas < $this ->sluzebniCesta->datumCasOd || $cas > $this ->sluzebniCesta->datumCasDo) {
                    throw new \Exception(
                        \Ron\ronText('Cas_mimo_rozsah_sc') . ' ' .
                        date('j.n.Y G:i', $this ->sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y G:i', $this ->sluzebniCesta->datumCasDo));
                }
            }
        }

        if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_KONTROLOVAT_PREKRYVANI)) {
            $this ->sluzebniCesta ->zkontrolujPrekryvaniSC($this ->database, $cas);
        }
    }


    function beforeInsertRecord($rec)
    {
        $this ->zkontrolujZaznam($rec);
        return parent::beforeInsertRecord($rec);
    }

    function beforeUpdateRecord($rec)
    {
        $this ->zkontrolujZaznam($rec);
        return parent::beforeUpdateRecord($rec);
    }


    /**
     * Volano po ulozeni zaznamu do databaze
     * @param DBRecord $rec
     */
    function afterRadekSCPost($rec)
    {
        // aktualizuje casy sluzebni cesty (pocatek a konec)
        if ( RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_CASY_AUTOMATICKY) ) {
            $this ->sluzebniCesta ->updateCasy($this ->database, $this);
        }
    }


    function afterInsertRecord($rec)
    {
        $this ->afterRadekSCPost($rec);
        return parent::afterInsertRecord($rec);
    }

    function afterUpdateRecord($rec)
    {
        $this ->afterRadekSCPost($rec);
        return parent::afterUpdateRecord($rec);
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/sluzebnicesty/radeksluzebnicestydialog.php <==
<?php
/**
 * stanislav.elbl, 19.10.2021 22:04
 */

namespace RonPortal\SluzebniCesty;

use Ron\Controls\FormField;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBRecord;
use Ron\DB\SqlStatement;
use Ron\StringUtils;
use RonPortal\Controls\RonPortalForm;
use RonPortal\RonPortalSettings;

class RadekSluzebniCestyDialog extends RonPortalForm
{
    protected $sluzebniCesta;


    /**
     * @param Database $database
     * @param SluzebniCesta $sluzebniCesta
     */
    function __construct($database, $sluzebniCesta)
    {
        parent::__construct($database, 'new', true);

        $this ->sluzebniCesta = $sluzebniCesta;

        $this ->cssClass = 'large-form rondialog ronform form-25-75';
        $this ->code = 'formradeksc';

        $this ->stornoAction = "#";

        $this ->htmlParams = array_merge($this ->htmlParams, [
            'id' => 'radek_sc_dialog',
            //'data-ronform-url' => '?menuid=sluzebnicestyjs&action=radeksc&idsc=' . $this ->sluzebniCesta ->id,
            'data-ronform-submit-url' => '?menuid=sluzebnicestyjs&action=zapisradeksc',
            'data-ronform-after-submit' => 'reload',
            'title' => \Ron\ronText('Radek_sluzebni_cesty')
        ]);

        $this ->sqlTableName = 'RadekSluzebniCesty';

        $this ->setXmlEventsName('SC_RADEK');

        $vychoziHodnoty = $this ->nactiHodnotyProNovyRadek();

        $this ->addField(FormField::FIELD_TYPE_HIDDEN)
            ->setFieldName('SluzebniCesta_ID') ->setDefaultValue($this ->sluzebniCesta ->id) ->setPrimary(true)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-sluzebnicesta_id')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'SluzebniCesta_ID']);

        $idParams = $this ->database ->createParameters();
        $this ->addField(FormField::FIELD_TYPE_ID)
            ->setFieldName('CisloRadku') ->setPrimary(true)
            ->setIdSqlFilter(new SqlStatement('SluzebniCesta_ID = ' . $idParams ->addParameter($this ->sluzebniCesta ->id), $idParams))
            ->addFieldCssClass('ronform-field')
            ->setCode('field-cisloradku')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'CisloRadku']);

        $this ->addField(FormField::FIELD_TYPE_DATEANDTIME)
            ->setFieldName('DatumCasOd') ->setCaption('Datum_a_cas')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-datumcasod')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'DatumCasOd'])
            ->setOtherHtmlParams2(['data-ronform-field-name' => 'DatumCasOd_time'])
            ->setDefaultValue([
                $vychoziHodnoty['datum'] ? StringUtils::format('date', $vychoziHodnoty['datum']) : '',
                $vychoziHodnoty['cas'] ? StringUtils::format('time', $vychoziHodnoty['cas']) : ''
            ]);

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('KodOperace') ->setCaption('Operace_sc')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-kodoperace')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'KodOperace'])
            ->setTranslationPrefix('db_operacedochazky_popis_')
            ->setSelectSql(
                'SELECT Kod, Popis FROM OperaceDochazky' .
                ' WHERE ' . ($this ->sluzebniCesta ->zahranicni ? 'UdalostZahranicniSC' : 'UdalostSluzebniCesty') . ' = 1 AND (%FILTER%)' .
                ' ORDER BY %ORDER%',
                '1 = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Misto') ->setCaption('Misto_sc')
            ->addFieldCssClass('ronform-field')
            ->setCode('field-misto')
            ->setOtherHtmlParams([
                'data-ronform-field-name' => 'Misto',
                'data-copy-target' => '#radek_sc_stat', 'data-copy-source' => 'stat', 'data-copy-empty-value' => '0'    // pri vyberu mista se nastavi stat
            ])
            ->setTranslationPrefix('db_mistosluzebnicesty_popis_')
            ->setItemsAttributes(['data-stat' => 2])    // v datovem atributu je ulozen stat
            ->setSelectSql(
                'SELECT Kod, Popis, Stat FROM MistoSluzebniCesty' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                'Aktivni = 1',
                'Popis'
            );

        $this ->addField()
            ->setFieldName('Popis') ->setCaption('Popis_radku_sc') ->setMaxLength(160)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-popis')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Popis']);

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Stat') ->setCaption('Stat') ->setDefaultValue($vychoziHodnoty['stat'])
            ->addFieldCssClass('ronform-field ronselect')
            ->setCode('field-stat')
            ->setFieldId('radek_sc_stat')   // slouzi pro nastaveni statu pri vyberu mista
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Stat'])
            ->setTranslationPrefix('db_stat_popis_')
            ->setSelectSql(
                'SELECT Kod, Popis FROM Stat' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                'PovolitVeSluzCeste = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DopravniProstredek') ->setCaption('Dopravni_prostredek') ->setDefaultValue($vychoziHodnoty['dopravniProstredek']) // default podle SC.
            ->addFieldCssClass('ronform-field')
            ->setCode('field-dopravniprostredek')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'DopravniProstredek'])
            ->setTranslationPrefix('db_dopravniprostredek_popis_')
            ->setVisible(false) // defaultne skryte, protoze je zadano uz v hlavicce SC
            ->setSelectSql(
                'SELECT Kod, Popis FROM DopravniProstredek' .
                ' WHERE (%FILTER%)' .
                ' ORDER BY %ORDER%',
                '1 = 1',
                'Popis'
            );

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_S') ->setCaption('Pocet_snidani') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_s')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_S', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_O') ->setCaption('Pocet_obedu') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_o')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_O', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_INT)
            ->setFieldName('PocetPJidel_V') ->setCaption('Pocet_veceri') ->setRequired(true) ->setDefaultValue(0)
            ->setFieldCssClass('ronform-field')
            ->setCode('field-pocetpjidel_v')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'PocetPJidel_V', 'size' => 2, 'maxlength' => 2]);

        $this ->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setCaption('Poznamka') ->setMaxLength(250)
            ->addFieldCssClass('ronform-field')
            ->setCode('field-poznamka')
            ->setOtherHtmlParams(['data-ronform-field-name' => 'Poznamka']);


        $this ->loadConfiguration();
    }


    public function getWhereCondition()
    {
        $params = $this ->database ->createParameters();

        $cisloRadku = isset($_POST['CisloRadku'])
            ? (int)$_POST['CisloRadku']
            : (int)$_GET['record'];

        return new SqlStatement(
            'SluzebniCesta_ID = ' . $params ->addParameter($this ->sluzebniCesta ->id) .
            ' AND CisloRadku = ' . $params ->addParameter($cisloRadku),
            $params);
    }


    /**
     * Urci vychozi hodnoty podle hlavicky sluzebni cesty a jiz existujicich radku
     * @return array
     * @throws \Ron\DB\DBException
     */
    private function nactiHodnotyProNovyRadek()
    {
        $params = $this ->database ->createParameters();

        $sql =
            'SELECT SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat, SluzebniCesta.DopravniProstredek, MAX(RadekSluzebniCesty.DatumCasOd)' .
            '  FROM SluzebniCesta LEFT OUTER JOIN RadekSluzebniCesty ON RadekSluzebniCesty.SluzebniCesta_ID = SluzebniCesta.Id ' .
            ' WHERE SluzebniCesta.Id = ' . $params ->addParameter((int)$this->sluzebniCesta ->id) .
            ' GROUP BY SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat, SluzebniCesta.DopravniProstredek';

        $cursor = $this ->database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        $cas = null;
        $datum = null;

        if ($row) {
            if ($row[4]) {
                // nejedna se o prvni radek - datum podle posledniho zaznamu, cas nevyplneny
                $datum = $cursor ->stringToTimestamp($row[4]);
            } else {
                // jedna se o prvni radek - datum a cas podle zacatku sl. cesty
                $datum = $cas = $cursor ->stringToTimestamp($row[0]);
            }
        }

        return [
            'datum' => $datum,
            'cas' => $cas,
            'stat' => $row[2],
            'dopravniProstredek' => $row[3]
        ];
    }


    /**
     * @param DBRecord $rec
     * @throws \Exception
     */
    private function zkontrolujZaznam($rec)
    {
        $cas = $rec['DatumCasOd'];

        if (!$this ->sluzebniCesta ->pocatekKonecPodleRadku) {
            // U sluzebni cesty neni nastaveno, ze se ma pocitat datum a cas pocatku a konce podle radku
            // Kontrola, jestli je zadany cas v rozsahu casu sluzebni cesty
            if (RonPortalSettings::getIntValue(SluzebniCestyUtils::SETTINGS_CASY_AUTOMATICKY)) {
                // cas pocatku a konce se nastavuje automaticky - kontroluje jenom datum
                if ($cas < DateUtils::startOfTheDay($this ->sluzebniCesta->datumCasOd) || $cas > DateUtils::endOfTheDay($this ->sluzebniCesta->datumCasDo)) {
                    throw new \Exception(\Ron\ronText('Datum_mimo_rozsah_sc') . ' ' .
                        date('j.n.Y', $this ->sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y', $this ->sluzebniCesta->datumCasDo));
                }
            } else {
                // ... ani cas se nenastavuje automaticky
                if ($cas < $this ->sluzebniCesta->datumCasOd || $cas > $this ->sluzebniCesta->datumCasDo) {
                    throw new \Exception(
                        \Ron\ronText('Cas_mimo_rozsah_sc') . ' ' .
                        date('j.n.Y G:i', $this ->sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y G:i', $this ->sluzebniCesta->datumCasDo));
                }
            }
        }

        $this ->sluzebniCesta ->zkontrolujPrekryvaniSC($this ->database, $cas);
    }


    public function getCsrfRequestId()
    {
        // csrf podle id sluzebni cesty
        return $this ->code . '_' . $this ->sluzebniCesta ->id;
    }


    function beforeInsertRecord($rec)
    {
        $this ->zkontrolujZaznam($rec);
        return parent::beforeInsertRecord($rec);
    }

    function beforeUpdateRecord($rec)
    {
        $this ->zkontrolujZaznam($rec);
        return parent::beforeUpdateRecord($rec);
    }


    /**
     * Volano po ulozeni zaznamu do databaze
     * @param DBRecord $rec
     */
    function afterRadekSCPost($rec)
    {
        // aktualizuje casy sluzebni cesty (pocatek a konec)
        if ( RonPortalSettings::getIntValue(SluzebniCestyUtils::SETTINGS_CASY_AUTOMATICKY) ) {
            $this ->sluzebniCesta ->updateCasy($this ->database, $this);
        }
    }


    function afterInsertRecord($rec)
    {
        $this ->afterRadekSCPost($rec);
        return parent::afterInsertRecord($rec);
    }

    function afterUpdateRecord($rec)
    {
        $this ->afterRadekSCPost($rec);
        return parent::afterUpdateRecord($rec);
    }

}
